@@ -21,17 +21,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=x86-64 -mtune=generic -O3 -pipe -fstack-protector-strong '
-           '-fno-plt -march=x86-64 -mtune=generic -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=x86-64 -mtune=generic -O3 '
-           '-pipe -fstack-protector-strong -fno-plt',
+           '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt -march=x86-64 '
+           '-mtune=generic -O3 -pipe -fno-plt -march=x86-64 -mtune=generic -O3 '
+           '-pipe -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O3 -pipe '
-                     '-fstack-protector-strong -fno-plt',
+ 'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt',
  'CONFIGURE_CFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
                             '-flto-partition=none -g -std=c99 -Wextra '
                             '-Wno-unused-result -Wno-unused-parameter '
@@ -48,8 +46,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'CFLAGS=-march=x86-64 -mtune=generic -O3 -pipe "
-                "-fstack-protector-strong -fno-plt' "
+                "'CFLAGS=-march=x86-64 -mtune=generic -O3 -pipe -fno-plt' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
@@ -617,14 +614,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=x86-64 -mtune=generic '
-                             '-O3 -pipe -fstack-protector-strong -fno-plt '
-                             '-march=x86-64 -mtune=generic -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -march=x86-64 '
-                             '-mtune=generic -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -flto=4 '
-                             '-fuse-linker-plugin -ffat-lto-objects '
-                             '-flto-partition=none -g -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-O3 -pipe -fno-plt -march=x86-64 -mtune=generic '
+                             '-O3 -pipe -fno-plt -march=x86-64 -mtune=generic '
+                             '-O3 -pipe -fno-plt -flto=4 -fuse-linker-plugin '
+                             '-ffat-lto-objects -flto-partition=none -g '
+                             '-std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wno-cast-function-type '
                              '-Werror=implicit-function-declaration -I. '
@@ -632,10 +627,9 @@ build_time_vars = {'ABIFLAGS': 'm',
                              '-D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=x86-64 -mtune=generic -O3 -pipe -fstack-protector-strong '
-              '-fno-plt -march=x86-64 -mtune=generic -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=x86-64 -mtune=generic '
-              '-O3 -pipe -fstack-protector-strong -fno-plt',
+              '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt -march=x86-64 '
+              '-mtune=generic -O3 -pipe -fno-plt -march=x86-64 -mtune=generic '
+              '-O3 -pipe -fno-plt',
  'PY_CFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
                      '-flto-partition=none -g -std=c99 -Wextra '
                      '-Wno-unused-result -Wno-unused-parameter '
@@ -643,11 +637,9 @@ build_time_vars = {'ABIFLAGS': 'm',
                      '-Werror=implicit-function-declaration',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=x86-64 -mtune=generic -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -march=x86-64 '
-                   '-mtune=generic -O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-march=x86-64 -mtune=generic -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -flto=4 '
+                   '-Wall -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                   '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                   '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt -flto=4 '
                    '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
                    '-g -std=c99 -Wextra -Wno-unused-result '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
@@ -669,13 +661,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=x86-64 -mtune=generic -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -march=x86-64 '
-                        '-mtune=generic -O3 -pipe -fstack-protector-strong '
                         '-fno-plt -march=x86-64 -mtune=generic -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -flto=4 '
-                        '-fuse-linker-plugin -ffat-lto-objects '
-                        '-flto-partition=none -g -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-fno-plt -march=x86-64 -mtune=generic -O3 -pipe '
+                        '-fno-plt -flto=4 -fuse-linker-plugin '
+                        '-ffat-lto-objects -flto-partition=none -g -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Wno-cast-function-type '
                         '-Werror=implicit-function-declaration -I. -I./Include '
